summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/kenterscheduledlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/kenterscheduledlg.cpp')
-rw-r--r--kmymoney2/dialogs/kenterscheduledlg.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/dialogs/kenterscheduledlg.cpp b/kmymoney2/dialogs/kenterscheduledlg.cpp
index 58d2e25..4c078f1 100644
--- a/kmymoney2/dialogs/kenterscheduledlg.cpp
+++ b/kmymoney2/dialogs/kenterscheduledlg.cpp
@@ -62,8 +62,8 @@ public:
KMyMoneyUtils::EnterScheduleResultCodeE m_extendedReturnCode;
};
-KEnterScheduleDlg::KEnterScheduleDlg(TQWidget *tqparent, const MyMoneySchedule& schedule) :
- KEnterScheduleDlgDecl(tqparent, "kenterscheduledlg"),
+KEnterScheduleDlg::KEnterScheduleDlg(TQWidget *parent, const MyMoneySchedule& schedule) :
+ KEnterScheduleDlgDecl(parent, "kenterscheduledlg"),
d(new Private)
{
d->m_schedule = schedule;
@@ -217,7 +217,7 @@ TransactionEditor* KEnterScheduleDlg::startEdit(void)
connect(editor, TQT_SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), editor, TQT_SLOT(slotReloadEditWidgets()));
// create the widgets, place them in the tqparent and load them with data
// setup tab order
d->m_tabOrderWidgets.clear();
KMyMoneyRegister::Action action = KMyMoneyRegister::ActionWithdrawal;
@@ -291,7 +291,7 @@ bool KEnterScheduleDlg::focusNextPrevChild(bool next)
w = tqApp->tqfocusWidget();
while(w && d->m_tabOrderWidgets.find(w) == -1) {
- // qDebug("'%s' not in list, use tqparent", w->className());
+ // qDebug("'%s' not in list, use parent", w->className());
w = w->parentWidget();
}
// if(w) qDebug("tab order is at '%s'", w->className());
@@ -217,7 +217,7 @@ TransactionEditor* KEnterScheduleDlg::startEdit(void)
connect(editor, TQT_SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), editor, TQT_SLOT(slotReloadEditWidgets()));
- // create the widgets, place them in the tqparent and load them with data
+ // create the widgets, place them in the parent and load them with data
// setup tab order
d->m_tabOrderWidgets.clear();